public inbox for gdb-cvs@sourceware.org
help / color / mirror / Atom feed
* [binutils-gdb] [arm] Rename arm_cache_is_sp_register to arm_is_alternative_sp_register
@ 2022-07-21 12:59 Luis Machado
  0 siblings, 0 replies; only message in thread
From: Luis Machado @ 2022-07-21 12:59 UTC (permalink / raw)
  To: gdb-cvs

https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=d65edaa0bc3f24537ecde3735b1fa041f36f4ab8

commit d65edaa0bc3f24537ecde3735b1fa041f36f4ab8
Author: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
Date:   Thu Jun 30 15:23:56 2022 +0100

    [arm] Rename arm_cache_is_sp_register to arm_is_alternative_sp_register
    
    All usages of this helper are really made to check if the register is
    one of the alternative SP registers (MSP/MSP_S/MSP_NS/PSP/PSP_S/PSP_NS)
    with the ARM_SP_REGNUM case being handled separately.
    
    Signed-off-by: Luis Machado <luis.machado@arm.com>
    Signed-off-by: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
    Signed-off-by: Yvan Roux <yvan.roux@foss.st.com>

Diff:
---
 gdb/arm-tdep.c | 15 ++++++---------
 1 file changed, 6 insertions(+), 9 deletions(-)

diff --git a/gdb/arm-tdep.c b/gdb/arm-tdep.c
index 3a1b52c2380..89c2779bbb5 100644
--- a/gdb/arm-tdep.c
+++ b/gdb/arm-tdep.c
@@ -479,14 +479,12 @@ arm_cache_set_active_sp_value (struct arm_prologue_cache *cache,
   gdb_assert_not_reached ("Invalid SP selection");
 }
 
 /* Return true if REGNUM is one of the stack pointers.  */
 
 static bool
-arm_cache_is_sp_register (struct arm_prologue_cache *cache,
-			  arm_gdbarch_tdep *tdep, int regnum)
+arm_is_alternative_sp_register (arm_gdbarch_tdep *tdep, int regnum)
 {
-  if ((regnum == ARM_SP_REGNUM)
-      || (regnum == tdep->m_profile_msp_regnum)
+  if ((regnum == tdep->m_profile_msp_regnum)
       || (regnum == tdep->m_profile_msp_s_regnum)
       || (regnum == tdep->m_profile_msp_ns_regnum)
       || (regnum == tdep->m_profile_psp_regnum)
@@ -503,8 +501,7 @@ static void
 arm_cache_switch_prev_sp (struct arm_prologue_cache *cache,
 			  arm_gdbarch_tdep *tdep, int sp_regnum)
 {
-  gdb_assert (sp_regnum != ARM_SP_REGNUM);
-  gdb_assert (arm_cache_is_sp_register (cache, tdep, sp_regnum));
+  gdb_assert (arm_is_alternative_sp_register (tdep, sp_regnum));
 
   if (tdep->have_sec_ext)
     gdb_assert (sp_regnum != tdep->m_profile_msp_regnum
@@ -2347,7 +2344,7 @@ arm_prologue_prev_register (struct frame_info *this_frame,
 
   /* The value might be one of the alternative SP, if so, use the
      value already constructed.  */
-  if (arm_cache_is_sp_register (cache, tdep, prev_regnum))
+  if (arm_is_alternative_sp_register (tdep, prev_regnum))
     {
       sp_value = arm_cache_get_sp_register (cache, tdep, prev_regnum);
       return frame_unwind_got_constant (this_frame, prev_regnum, sp_value);
@@ -3694,7 +3691,7 @@ arm_m_exception_prev_register (struct frame_info *this_frame,
 
   /* The value might be one of the alternative SP, if so, use the
      value already constructed.  */
-  if (arm_cache_is_sp_register (cache, tdep, prev_regnum))
+  if (arm_is_alternative_sp_register (tdep, prev_regnum))
     {
       sp_value = arm_cache_get_sp_register (cache, tdep, prev_regnum);
       return frame_unwind_got_constant (this_frame, prev_regnum, sp_value);


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-07-21 12:59 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -479,14 +479,12 @@ arm_cache_set_active_sp_value (struct arm_prologue_cache *cache,
 }
 
-/* Return true if REGNUM is one of the stack pointers.  */
+/* Return true if REGNUM is one of the alternative stack pointers.  */
 
 static bool
2022-07-21 12:59 [binutils-gdb] [arm] Rename arm_cache_is_sp_register to arm_is_alternative_sp_register Luis Machado

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).